@@ -681,10 +681,10 @@ def get_expected_generated_files(
 
         ## DERIVE the EXPECTED root-level files for post removal, based on docs-builer type
         # we leverage the same production mapping of builder_id to files
-        from cookiecutter_python.hooks.post_gen_project import builder_id_2_files
+        from cookiecutter_python.hooks.post_gen_project import DOCS_FILES_EXTRA
 
         for docs_builder_id, builder_files in (
-            (k, v) for k, v in builder_id_2_files.items() if k != config.data['docs_builder']
+            (k, v) for k, v in DOCS_FILES_EXTRA.items() if k != config.data['docs_builder']
         ):
             assert all(
                 [isinstance(x, str) for x in builder_files]
